@@ -1,4 +1,5 @@
 package IO::All::DBM;
+$IO::All::DBM::VERSION = '0.58';
 use strict;
 use warnings;
 use IO::All::File -base;
@@ -17,7 +18,7 @@ sub dbm {
 
 sub assert_open {
     my $self = shift;
-    return $self->tied_file 
+    return $self->tied_file
       if $self->tied_file;
     $self->open;
 }
@@ -56,7 +57,7 @@ sub open {
         $self->_dbm_class->import;
         my $type = eval '$DB_HASH'; die $@ if $@;
         # XXX Not sure about this warning
-        warn "Using DB_File::Lock in IO::All without the rdonly or rdwr method\n" 
+        warn "Using DB_File::Lock in IO::All without the rdonly or rdwr method\n"
           if not ($self->_rdwr or $self->_rdonly);
         my $flag = $self->_rdwr ? 'write' : 'read';
         $mode = $self->_rdwr ? O_RDWR : O_RDONLY;
@@ -72,7 +73,7 @@ sub tie_dbm {
     my $self = shift;
     my $hash;
     my $filename = $self->name;
-    my $db = tie %$hash, $self->_dbm_class, $filename, $self->mode, $self->perms, 
+    my $db = tie %$hash, $self->_dbm_class, $filename, $self->mode, $self->perms,
         @{$self->_dbm_extra}
       or $self->throw("Can't open '$filename' as DBM file:\n$!");
     $self->add_utf8_dbm_filter($db)
@@ -89,7 +90,9 @@ sub add_utf8_dbm_filter {
     $db->filter_fetch_value(sub { utf8::decode($_) });
 }
 
-=head1 NAME 
+=encoding utf8
+
+=head1 NAME
 
 IO::All::DBM - DBM Support for IO::All
 
@@ -101,11 +104,13 @@ See L<IO::All>.
 
 =head1 AUTHOR
 
-Brian Ingerson <INGY@cpan.org>
+Ingy döt Net <ingy@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2004. Brian Ingerson. All rights reserved.
+Copyright (c) 2004. Brian Ingerson.
+
+Copyright (c) 2006, 2008. Ingy döt Net.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
